@@ -1,5 +1,10 @@
 available_functions = '''
 
+	...try this,
+
+	from vixtor import threeDvector as vix
+	print( vix.angbw2line( printing = True ))
+
 >>> Made with LOVE and HARDWORK...
 
 	mod(vector=[2,1,2])
@@ -38,4 +43,4 @@ available_functions = '''
 reasoning but imagination. – A.DEMORGAN
 '''
 
-print('\n>>> Available functions are...\n', available_functions)
+print('\n>>> Available functions in vixtor Package are...\n', available_functions)
